from .async_client import (
    CustomerExtensionSettingServiceAsyncClient as CustomerExtensionSettingServiceAsyncClient,
)
from .client import (
    CustomerExtensionSettingServiceClient as CustomerExtensionSettingServiceClient,
)

__all__ = [
    "CustomerExtensionSettingServiceClient",
    "CustomerExtensionSettingServiceAsyncClient",
]
