from .async_client import (
    FeedItemTargetServiceAsyncClient as FeedItemTargetServiceAsyncClient,
)
from .client import FeedItemTargetServiceClient as FeedItemTargetServiceClient

__all__ = ["FeedItemTargetServiceClient", "FeedItemTargetServiceAsyncClient"]
