from .async_client import (
    CustomerFeedServiceAsyncClient as CustomerFeedServiceAsyncClient,
)
from .client import CustomerFeedServiceClient as CustomerFeedServiceClient

__all__ = ["CustomerFeedServiceClient", "CustomerFeedServiceAsyncClient"]
