from .async_client import (
    CampaignExtensionSettingServiceAsyncClient as CampaignExtensionSettingServiceAsyncClient,
)
from .client import (
    CampaignExtensionSettingServiceClient as CampaignExtensionSettingServiceClient,
)

__all__ = [
    "CampaignExtensionSettingServiceClient",
    "CampaignExtensionSettingServiceAsyncClient",
]
